package jsfdemo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;
import javax.faces.model.SelectItem;

public class ApplicationLocales implements Serializable, Converter {
	/**
	 * 
	 */
	private static final long serialVersionUID = -4127938475573644190L;
	private List<SelectItem> localesList;

	public ApplicationLocales() {
		Iterator<Locale> localesIterator = FacesContext.getCurrentInstance()
				.getApplication().getSupportedLocales();
		
		this.localesList = new ArrayList<SelectItem>();
		localesList.add(new SelectItem(
				FacesContext.getCurrentInstance().getApplication().getDefaultLocale()));
		while (localesIterator.hasNext()) {
			Locale locale = (Locale) localesIterator.next();
			localesList.add(new SelectItem(locale, locale.getDisplayName()));
		}
	}

	public List<SelectItem> getLocalesList() {
		return localesList;
	}

	@Override
	public Object getAsObject(FacesContext facesContext, UIComponent component,
			String value) throws ConverterException {
		String[] langAndCountry = value.split("_");
		if (langAndCountry.length == 1) {
			return new Locale(langAndCountry[0]);
		} else if (langAndCountry.length == 2) {
			return new Locale(langAndCountry[0], langAndCountry[1]);
		} else {
			throw new ConverterException("Cannot convert the locale " + value);
		}
	}

	@Override
	public String getAsString(FacesContext facesContext, UIComponent component,
			Object value) throws ConverterException {
		if (value instanceof Locale) {
			return value.toString();
		}
		return null;
	}

}
